/****************************************************************
 *  Vidalia is distributed under the following license:
 *
 *  Copyright (C) 2006,  Matt Edman, Justin Hipple
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 *  Boston, MA  02110-1301, USA.
 ****************************************************************/

/** 
 * \file replyline.h
 * \version $Id: replyline.h 1735 2007-05-13 07:23:57Z edmanm $
 * \brief Reply from a previous control command sent to Tor
 */

#ifndef _REPLYLINE_H
#define _REPLYLINE_H

#include <QStringList>


class ReplyLine
{
public:
  ReplyLine();
  ReplyLine(QString status, QString message);
  ReplyLine(QString status, QString message, QString data);

  /** Set the status code to <b>status</b>. */
  void setStatus(QString status);
  /** Returns the status code for this reply line. */
  QString getStatus() const;

  /** Sets the ReplyText message this reply line to <b>msg</b>. */
  void setMessage(QString msg);
  /** Returns the ReplyText portion of this reply line. */
  QString getMessage() const;

  /** Appends <b>data</b> to this reply line. */
  void appendData(QString data);
  /** Returns a QStringList of all data lines for this reply line. */
  QStringList getData() const;
  
  /** Returns the entire contents of this reply line, including the status,
   * message, and any extra data. */
  QString toString() const;

private:
  /** Unescapes special characters in <b>str</b> and returns the unescaped
   * result. */
  static QString unescape(QString str);
  
  QString _status;    /**< Response status code. */
  QString _message;   /**< ReplyText portion of this reply line. */
  QStringList _data;  /**< Contents of any DataReplyLines in this line. */
};

#endif

